/*
 * File:   simpleprocess.h
 * Author: askv
 *
 * Created on September 18, 2010, 8:31 PM
 */

#ifndef SIMPLEPROCESS_H
#define SIMPLEPROCESS_H

#ifdef  __cplusplus
extern "C" {
#endif




#ifdef  __cplusplus
}
#endif
namespace rtengine
{

extern Glib::Thread *batchThread;
}
#endif  /* SIMPLEPROCESS_H */

